;;; DO NOT MODIFY THIS FILE
(if (featurep 'locale-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "locale/_pkg.el")

(package-provide 'locale :version 1.25 :author-version "No-Upstream-Ver" :type 'regular)

;;;***

(provide 'locale-autoloads)
