;;; locale-start.el --- startup.el customized for the ro locale.

;; Copyright (C) 1985-6, 1990, 1992-1995, 1997 Free Software Foundation, Inc.
;; Copyright (c) 1993-1997 Sun Microsystems, Inc.
;; Copyright (C) 1995 Board of Trustees, University of Illinois

;; Maintainer: XEmacs Development Team
;; Keywords: internal

;; This file is part of XEmacs.

;; XEmacs is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; XEmacs is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with XEmacs; see the file COPYING.  If not, write to the Free
;; Software Foundation, 59 Temple Place - Suite 330, Boston, MA
;; 02111-1307, USA.


;;; Synched up with:  Not in FSF

;;; Commentary:

;;			This file, being an .el file, 
;;			must be in ISO 2022 encoding after installation.
;; @(#)locale-start.el.euc	1.7 97/03/06 13:43:21

;;; Code:

(if (fboundp 'splash-frame-body)

;; old way

(defun splash-frame-body ()
  (set-buffer-file-coding-system 'iso-8859-2)
  `("\n" ,(emacs-version) "\n"
    ,@(if (string-match "beta" emacs-version)
	  `( (face (bold blue) ( "This is an Experimental version of XEmacs. "
				 " Type " (key describe-beta)
				 " to see what this means.\n")))
	`( "\n"))
    (face bold-italic "\
Copyright (C) 1985-1997 Free Software Foundation, Inc.
Copyright (C) 1990-1994 Lucid, Inc.
Copyright (C) 1993-1997 Sun Microsystems, Inc. All Rights Reserved.
Copyright (C) 1994-1996 Board of Trustees, University of Illinois
Copyright (C) 1995-2004 Ben Wing\n\n")
    
    ,@(if (featurep 'sparcworks)
          `( "\
Sun ofer-Bă suport doar pentru pachetul de integrare WorkShop/XEmacs.-A
Toate celelalte pachete XEmacs v-Bă sunt oferite \"FĂRĂ NICI O GARANȚIE\".-A
Pute-Bți obține detalii complete tastând " (key describe-no-warranty)-A
" pentru a v-Bă referi la a doua versiune de GPL, datată iunie 1991.\n\n"x-A
,@(let ((lang (or (getenv "LC_ALL") (getenv "LC_MESSAGES") (getenv "LANG"))))
    (if (and
         (not (featurep 'mule))         ; Already got mule?
         (not (eq 'tty (console-type))) ; No Mule support on tty's yet
         lang                           ; Non-English locale?
         (not (string= lang "C"))
         (not (string-match "^en" lang))
         (locate-file "xemacs-mule" exec-path)) ; Comes with Sun WorkShop
        '( "\
Aceast-Bă versiune de XEmacs a fost construită cu suport numai pentru-A
limbile Latin-1.  Pentru a putea folosi alte limbi trebuie s-Bă rulați o-A
versiune de XEmacs Multi-Lingval (`Mule'), fie rul-Bând comanda-A
`xemacs-mule', fie folosind resursa X `ESERVE*defaultXEmacsPath:
xemacs-mule' c-Bând porniți XEmacs-ul din Sun WorkShop.\n\n"))))-A

        '("XEmacs-ul vine f-Bără ABSOLUT NICI O GARANȚIE; tastați "-A
          (key describe-no-warranty) " pentru detalii complete.\n"))
    
    "Pute-Bți distribui copii de XEmacs; tastați "-A
    (key describe-copying) " pentru a afla condi-Bțiile.\n"-A
    "Tasta-Bți " (key describe-distribution)-A
    " pentru a afla cum pute-Bți obține cea mai recentă versiune.\n\n"-A

    "Tasta-Bți " (key help-command)-A
    " sau folosi-Bți meniul " (face bold "Help") " pentru a obține ajutor.\n"-A
    "Tasta-Bți " (key advertised-undo)-A
    " pentru a anula schimb-Bările  (`C-' înseamnă că trebuie să folosiți tasta Control).\n"-A
    "Pentru a ie-Bși din XEmacs, tastați " (key save-buffers-kill-emacs) ".\n"-A
    "Tasta-Bți " (key help-with-tutorial)-A
    " pentru un tutorial despre folosirea XEmacs-ului.\n"
    "Tasta-Bți " (key info) " pentru a intra în Info, "-A
    "mod ce poate fi folosit pentru a citi documenta-Bția online.\n"-A
    (face (bold red) ( "\
Pentru sugestii -Bși răspunsuri la întrebări frecvente, citiți FAQ-ul XEmacs-ului.-A
\(Este -Bîn meniul Help, dar puteți tasta și " (key xemacs-local-faq) " [F mare!].\)"))))-A

;; new way

(defun splash-screen-window-body ()
  `(
     (face (blue bold underline)
	   "#### Entries utiles dans le menu Aide:\n\n")
     ,@(if (string-match "beta" emacs-version)
	   `((face bold "Beta Info:")
	     (face (red bold)
		   "                      Ceci est une version expérimentale d'XEmacs.\n"))
	 `( ""))
     (face bold "XEmacs FAQ:")
     "                     Lisez la FAQ d'XEmacs.\n"
     (face bold "Info (Online Docs):")
     "             Lisez la documentation en-ligne.\n"
     (face bold "Tutorial:")
     "                       Lisez le tutoriel d'XEmacs.\n"
     (face bold "Samples->View Sample init.el:") ;; #### translation
     "   Un fichier utile d'initialization.\n"
     (face bold "About XEmacs:")
     "                   À propos des développeurs d'XEmacs.\n"
     "\n"
     (face (bold blue) "Site web d'XEmacs:")
     "                 http://www.xemacs.org/\n\n"
     ,@(if (featurep 'sparcworks)
	   `( "\
Sun fournit un support pour le paquet d'intégration Workshop/XEmacs seulement.
Tous les autres paquets d'XEmacs sont fournis «TEL QUEL».\n"
	      ,@(let ((lang (or (getenv "LC_ALL") (getenv "LC_MESSAGES")
				(getenv "LANG"))))
		  (if (and
		       (not (featurep 'mule)) ;; Already got mule?
		       lang ;; Non-English locale?
		       (not (string= lang "C"))
		       (not (string-match "^en" lang))
		       ;; Comes with Sun WorkShop
		       (locate-file "xemacs-mule" exec-path))
		      '( "\
Cette version d'XEmacs a été compilée avec le support Latin-1 seul.
Pour manipuler d'autres langages, vous devez disposer d'une version
multi-lingue (`Mule') d'XEmacs, soit en utilisant la commande `xemacs-mule',
soit en positionnant la resource X `ESERVE*defaultXEmacsPath: xemacs-mule' en
démarrant XEmacs depuis le WorkShop de Sun.
\n")))))
     (face italic "\
Copyright (C) 1985-1999 Free Software Foundation, Inc.
Copyright (C) 1990-1994 Lucid, Inc.
Copyright (C) 1993-1997 Sun Microsystems, Inc. Tous droits réservés.
Copyright (C) 1994-1996 Board of Trustees, University of Illinois.
Copyright (C) 1995-2004 Ben Wing.\n")
     ))

(defun splash-screen-tty-body ()
  `(
    (face italic "[`C-' signifie la touche Contrôle,`M-' signifie la touche Méta]\n\n")
     ,@(if (string-match "beta" emacs-version)
	   `((key describe-beta)
	     ": " (face (red bold)
			"Ceci est une version expérimentale d'XEmacs.\n"))
	 `( "\n"))
     ((key xemacs-local-faq)
      ": Lisez la FAQ d'XEmacs. (Un F " (face underline "majuscule") " !)\n")
     ((key info) ": Lisez la documentation en-ligne.\n")
     ((key help-command)
      ": De l'aide sur l'utilisation d'XEmacs.\n")
     ((key help-with-tutorial)
      ": Lisez le tutoriel d'XEmacs.\n")
     ((key view-sample-init-el) ;; #### translation?
      ": Regardez le fichier sample init.el.\n")
     ((key about-xemacs) ": À propos des développeurs d'XEmacs.\n\n")
     (face (bold blue) "Site web d'XEmacs: ") 
     "http://www.xemacs.org/\n\n"
     (face italic "\
Copyright (C) 1985-1999 Free Software Foundation, Inc.
Copyright (C) 1990-1994 Lucid, Inc.
Copyright (C) 1993-1997 Sun Microsystems, Inc. Tous droits réservés.
Copyright (C) 1994-1996 Board of Trustees, University of Illinois.
Copyright (C) 1995-2004 Ben Wing.")
;      ((key find-file) ": visiter un fichier\n")
;      ((key save-buffer) ": sauvegarder les modifiactions\n")
;      ((key advertised-undo) ": annuler les modifications\n")
;      ((key save-buffers-kill-emacs) ": sortir d'XEmacs\n")
     ))
)

(defun command-line-do-help (arg)
  "Print the XEmacs usage message and exit."
  (setq terminal-coding-system 'iso-2022)
  ;;(set-terminal-coding-system 'iso-8859-2)
  ;; (set-console-tty-output-coding-system)
  (let ((standard-output 'external-debugging-output))
    (princ (concat "\n" (emacs-version) "\n\n"))
    (princ
     (if (featurep 'x)
	 (concat (emacs-name)
		 " accept-Bă toate opțiunile în linia de comandă ale Toolkit-ului X standard.\n"-A
		 "-BÎn plus, următoarele")-A
       "Urm-Bătoarele"))-A
    (princ " op-Bțiuni sunt acceptate:-A

  -t <dispozitiv>       A se folosi TTY <dispozitiv> -Bîn loc de terminal pentru-A
			intrare -Bși ieșire.  Implică opțiunea -nw.-A
  -nw                   A se inhiba folosirea oric-Băror capabilități de afișare-A
 			grafic-Bă: se va folosi terminalul curent.-A
  -batch                Execu-Bție neinteractivă (mesajele sunt trimise la-A
			stderr).
  -debug-init           A se intra -Bîn depanator în cazul unei erori în-A
			fi-Bșierul de inițializare.-A
  -unmapped             A nu se mapa cadrul ini-Bțial.-A
  -no-site-file         A nu se -Bîncărca fișierul de inițializare specific-A
			site-ului (site-start.el).
  -no-init-file         A nu se -Bîncărca fișierul de inițializare specific-A
			utilizatorului (~/.emacs).
  -no-early-packages	A nu se procesa pachetele -Bîncărcate devreme.-A
  -no-autoloads		A nu se -Bîncărca la inițializare fișierele cu simboli-A
			globali (auto-autoloads). Implic-Bă și `-vanilla'.-A
  -vanilla		Echivalent cu -q -no-site-file -no-early-packages.
  -q                    La fel ca -no-init-file.
  -user <utilizator>    A se -Bîncărca fișierul de inițializare al-A
			<utilizator>-ului, -Bîn locul celui propriu.-A
  -u <utilizator>       La fel ca -user.\n")
   (let ((l command-switch-alist)
	  (insert (lambda (&rest x)
		    (princ "  ")
		    (let ((len 2))
		      (while x
			(princ (car x))
			(incf len (length (car x)))
			(setq x (cdr x)))
		      (when (>= len 24)
			(terpri) (setq len 0))
		      (while (< len 24)
			(princ " ")
			(incf len))))))
      (while l
        (let ((name (car (car l)))
              (fn (cdr (car l)))
	      doc arg cons)
	  (cond
	   ((and (symbolp fn) (get fn 'undocumented)) nil)
	   (t
	    (setq doc (documentation fn))
	    (if (member doc '(nil "")) (setq doc "(undocumented)"))
	    (cond ((string-match "\n\\(<.*>\\)\n?\\'" doc)
		   ;; Doc of the form "The frobber switch\n<arg1> <arg2>"
		   (setq arg (substring doc (match-beginning 1) (match-end 1))
			 doc (substring doc 0 (match-beginning 0))))
		  ((string-match "\n+\\'" doc)
		   (setq doc (substring doc 0 (match-beginning 0)))))
	    (if (and (setq cons (rassq fn command-switch-alist))
		     (not (eq cons (car l))))
		(setq doc (format "Same as %s." (car cons))))
	    (if arg
		(funcall insert name " " arg)
	      (funcall insert name))
	    (princ doc)
	    (terpri))))
        (setq l (cdr l))))
    (princ (concat "\
  +N <fi-Bșier>             A se începe afișarea <fișier>-ului la linia N.-A

Orice altceva este considerat nume de fi-Bșier și este încărcat într-un-A
buffer -Bîn vederea editării.-A

" (emacs-name) " are manuale -Bși un tutorial online.  Tastați ^Ht (Control-h t) după-A
pornirea XEmacs-ului pentru a lansa tutorialul.  Tasta-Bți ^Hi pentru a-A
citi documenta-Bția.  Tastați ^H^H^H (Control-h Control-h Control-h)-A
pentru a ob-Bține mai multe feluri de ajutor.\n")-A

    (kill-emacs 0))))


;;; locale-start.el ends here
